# Schema Store

This crate provides the schema store for TOML.

Currently, this depends on [JSON Schema](https://json-schema.org/), and includes schema management and the ability to automatically read schemas from the [JSON Schema Store](https://www.schemastore.org/).
In the future, it may support [TOML Schema](https://github.com/toml-lang/toml/issues/792), but there is no progress on the specification.
